@@ -28,6 +28,6 @@ void thriftydrinker::calculate()
     float volume = volumes[ui->comboBox->currentIndex()]; //mL
     float cost = ui->doubleSpinBox->value();
     if(cost)
-        snprintf(test,80,"That is equivalent for paying $%.02lf for a can of Miller Lite!", cost/(proof/2*volume*.01)*MILLERFACTOR);
+	snprintf(test,80,"That is equivalent to paying $%.02lf for a can of Miller Lite!", cost/(proof/2*volume*.01)*MILLERFACTOR);
     ui->label_4->setText(test);
 }
